==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Preparing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Просмотр журналов</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Обновление успешно завершено</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Ваш компьютер перезагрузится через %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Ваш компьютер выключится через %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Скрыть журналы</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Ошибка обновления</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Неизвестная ошибка</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Сбой резервного копирования</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Не удается выполнить резервное копирование системы. Если Вы продолжите обновление, позже Вы не сможете выполнить откат к старой системе.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Недостаточно места на диске. Пожалуйста, очистите Ваш диск и повторите попытку.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Не удалось подключиться к службам резервного копирования. Пожалуйста, проверьте и повторите попытку еще раз.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Не удалось подключиться к службам обновления. Пожалуйста, проверьте и повторите попытку еще раз.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Ошибка зависимостей</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Ошибка DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Восстановить снова</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Прервать</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Перейти к обновлению</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Подготовка к обновлению...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Не выключайте компьютер при установке обновлений. В противном случае Ваша система может быть повреждена.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.21.tar.xz: BUILD/src/dde-update/translations/dde-update_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Preparing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Обновление успешно завершено</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Ваш компьютер перезагрузится через %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Ваш компьютер выключится через %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Ошибка обновления</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Неизвестная ошибка</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Сбой резервного копирования</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Не удается выполнить резервное копирование системы. Если Вы продолжите обновление, позже Вы не сможете выполнить откат к старой системе.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Недостаточно места на диске. Пожалуйста, очистите Ваш диск и повторите попытку.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Не удалось подключиться к службам резервного копирования. Пожалуйста, проверьте и повторите попытку еще раз.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Не удалось подключиться к службам обновления. Пожалуйста, проверьте и повторите попытку еще раз.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Ошибка зависимостей</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Ошибка DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Восстановить снова</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Прервать</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Перейти к обновлению</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Подготовка к обновлению...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Не выключайте компьютер при установке обновлений. В противном случае Ваша система может быть повреждена.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
